=====
Quade
=====

.. image:: https://travis-ci.org/makingspace/quade.svg?branch=master
    :target: https://travis-ci.org/makingspace/quade

.. image:: https://codecov.io/gh/makingspace/quade/branch/master/graph/badge.svg
    :target: https://codecov.io/gh/makingspace/quade

Meet Quade, the friendly QA tool for Django!

.. image:: docs/_static/quade_200x200.png

Quade is a Django app that makes quality assurance testing better. It
handles repeatedly setting up the same data so you don't have to.

Installation
------------

* Check out the Quickstart_!

.. _Quickstart: https://quade.readthedocs.io/en/stable/quickstart.html

Links
-----

* `Source on Github`_
* `Documentation at Read the Docs`_

.. _Source on Github: https://github.com/makingspace/quade
.. _Documentation at Read the Docs: https://quade.readthedocs.io/
